Index: code/branches/unity_build/cmake/tools/SourceFileUtilities.cmake
===================================================================
--- code/branches/unity_build/cmake/tools/SourceFileUtilities.cmake	(revision 8440)
+++ code/branches/unity_build/cmake/tools/SourceFileUtilities.cmake	(revision 8558)
@@ -25,8 +25,8 @@
  #                             adds the current directory.
  #                             Also compiles multiple source files into a single
- #                             one by including them
- #                             Use COMPILATION_[BEGIN|END] in
+ #                             translation unit (faster)
+ #                             Use [END_]BUILD_UNIT in
  #                             [ADD|SET]_SOURCE_FILES and specify the name of
  #                             the new source file after COMPILATION_BEGIN
  #    GET_ALL_HEADER_FILES   - Finds all header files recursively.
  #    GENERATE_SOURCE_GROUPS - Set Visual Studio source groups.
@@ -36,5 +36,5 @@
   SET(_source_files)
   FOREACH(_file ${ARGN})
-    IF(_file MATCHES "^(COMPILATION_BEGIN|COMPILATION_END)$")
+    IF(_file MATCHES "^(BUILD_UNIT|END_BUILD_UNIT)$")
       # Append keywords verbatim
       LIST(APPEND _source_files ${_file})
@@ -25,8 +25,8 @@
  #                             [ADD|SET]_SOURCE_FILES and specify the name of
- #                             the new source file after COMPILATION_BEGIN
+ #                             the new source file after BUILD_UNIT
  #    GET_ALL_HEADER_FILES   - Finds all header files recursively.
  #    GENERATE_SOURCE_GROUPS - Set Visual Studio source groups.
Index: code/branches/unity_build/cmake/tools/TargetUtilities.cmake
===================================================================
--- code/branches/unity_build/cmake/tools/TargetUtilities.cmake	(revision 8440)
+++ code/branches/unity_build/cmake/tools/TargetUtilities.cmake	(revision 8558)
@@ -95,36 +95,36 @@
   PARSE_MACRO_ARGUMENTS("${_switches}" "${_list_names}" ${ARGN})
 
   # Process source files with support for compilations
   # Note: All file paths are relative to the root source directory, even the
-  #       name of the compilation file.
+  #       name of the build unit.
   SET(_${_target_name}_source_files)
-  SET(_get_compilation_file FALSE)
-  SET(_add_to_compilation FALSE)
+  SET(_get_build_unit_file FALSE)
+  SET(_add_to_build_unit FALSE)
   FOREACH(_file ${_arg_SOURCE_FILES})
-    IF(_file STREQUAL "COMPILATION_BEGIN")
-      # Next file is the name of the compilation
-      SET(_get_compilation_file TRUE)
-    ELSEIF(_file STREQUAL "COMPILATION_END")
-      IF(NOT _compilation_file)
-        MESSAGE(FATAL_ERROR "No name provided for source file compilation")
-      ENDIF()
-      IF(NOT DISABLE_COMPILATIONS)
-        IF(NOT _compilation_include_string)
-          MESSAGE(STATUS "Warning: Empty source file compilation!")
-        ENDIF()
-        IF(EXISTS ${_compilation_file})
-          FILE(READ ${_compilation_file} _include_string_file)
-        ENDIF()
-        IF(NOT _compilation_include_string STREQUAL "${_include_string_file}")
-          FILE(WRITE ${_compilation_file} "${_compilation_include_string}")
-        ENDIF()
-        LIST(APPEND _${_target_name}_source_files ${_compilation_file})
-      ENDIF()
-      SET(_add_to_compilation FALSE)
-    ELSEIF(_get_compilation_file)
-      SET(_compilation_file ${CMAKE_BINARY_DIR}/${_file})
-      SET(_get_compilation_file FALSE)
-      SET(_add_to_compilation TRUE)
-      SET(_compilation_include_string)
+    IF(_file STREQUAL "BUILD_UNIT")
+      # Next file is the name of the build unit
+      SET(_get_build_unit_file TRUE)
+    ELSEIF(_file STREQUAL "END_BUILD_UNIT")
+      IF(NOT _build_unit_file)
+        MESSAGE(FATAL_ERROR "No name provided for build unit")
+      ENDIF()
+      IF(NOT DISABLE_BUILD_UNITS)
+        IF(NOT _build_unit_include_string)
+          MESSAGE(STATUS "Warning: Empty build unit!")
+        ENDIF()
+        IF(EXISTS ${_build_unit_file})
+          FILE(READ ${_build_unit_file} _include_string_file)
+        ENDIF()
+        IF(NOT _build_unit_include_string STREQUAL "${_include_string_file}")
+          FILE(WRITE ${_build_unit_file} "${_build_unit_include_string}")
+        ENDIF()
+        LIST(APPEND _${_target_name}_source_files ${_build_unit_file})
+      ENDIF()
+      SET(_add_to_build_unit FALSE)
+    ELSEIF(_get_build_unit_file)
+      SET(_build_unit_file ${CMAKE_BINARY_DIR}/${_file})
+      SET(_get_build_unit_file FALSE)
+      SET(_add_to_build_unit TRUE)
+      SET(_build_unit_include_string)
     ELSE()
       # Default, add source file
@@ -146,8 +146,8 @@
       LIST(APPEND _${_target_name}_source_files ${_file})
 
-      # Handle compilations
-      IF(_add_to_compilation AND NOT DISABLE_COMPILATIONS)
+      # Handle build units
+      IF(_add_to_build_unit AND NOT DISABLE_BUILD_UNITS)
         IF(_file MATCHES "\\.(c|cc|cpp|cxx)$")
-          SET(_compilation_include_string "${_compilation_include_string}#include \"${_file}\"\n")
+          SET(_build_unit_include_string "${_build_unit_include_string}#include \"${_file}\"\n")
         ENDIF()
         # Don't compile these files, even if they are source files
@@ -95,36 +95,36 @@
   PARSE_MACRO_ARGUMENTS("${_switches}" "${_list_names}" ${ARGN})
 
-  # Process source files with support for compilations
+  # Process source files with support for build units
   # Note: All file paths are relative to the root source directory, even the
